@@ -32,7 +32,6 @@
 #'         greater than 0.05.
 #'
 #' @examples
-#' library(sjmisc)
 #' data(efc)
 #' # differing from population
 #' chisq_gof(efc$e42dep, c(0.3,0.2,0.22,0.28))
@@ -40,9 +39,8 @@
 #' chisq_gof(efc$e42dep, prop.table(table(efc$e42dep)))
 #'
 #' # goodness-of-fit test for logistic regression
-#' efc$services <- dicho(efc$tot_sc_e, "v", 0, as.num = TRUE)
-#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
-#'            data = efc,
+#' efc$services <- ifelse(efc$tot_sc_e > 0, 1, 0)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep, data = efc,
 #'            family = binomial(link = "logit"))
 #' chisq_gof(fit)
 #'
@@ -86,7 +84,7 @@ chisq_gof <- function(x, prob = NULL, weights = NULL) {
       return(invisible(NULL))
     }
     # performs a Chi-square goodnes-of-fit-test
-    if (!is.null(weights)) x <- sjmisc::weight(x, weights)
+    if (!is.null(weights)) x <- weight(x, weights)
     dummy <- as.vector(table(x))
     # goodness of fit-test. x is one-dimensional and
     # y not given
@@ -120,13 +118,10 @@ chisq_gof <- function(x, prob = NULL, weights = NULL) {
 #' @seealso \code{\link{r2}}
 #'
 #' @examples
-#' library(sjmisc)
 #' data(efc)
-#'
 #' # goodness-of-fit test for logistic regression
-#' efc$services <- dicho(efc$tot_sc_e, "v", 0, as.num = TRUE)
-#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
-#'            data = efc,
+#' efc$services <- ifelse(efc$tot_sc_e > 0, 1, 0)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep, data = efc,
 #'            family = binomial(link = "logit"))
 #' hoslem_gof(fit)
 #'
